
from colorama import Fore, Back, Style
from copy import deepcopy

LEFT = 0
RIGHT = 1
CENTER = 2
LEFT_AUTO = 3
RIGHT_AUTO = 4
CENTER_AUTO = 5

class BeutySpan():
    def __init__(self, color = Fore.WHITE, padding : int= 0, padStyle : int = RIGHT, bgColor= '', style :str = '', l_sep : str= '[ ', r_sep: str = ' ]', sepColor:str = Fore.WHITE, postProccessor = None):
        self.textColor = color
        self.textPadding = padding
        self.textPaddingDirection = padStyle
        self.textBackgroundColor = bgColor
        self.textStyle = style
        self.l_sep = l_sep
        self.r_sep = r_sep
        self.seperatorColor = sepColor
        self.postProcessor = postProccessor

class BeutyPrint():

    def __init__(self, format: list[BeutySpan] = [BeutySpan()]):

        self.formatRules = format
        # self.defaultSpan = defaultSpan

    def getFormatted(self, format: list[BeutySpan], messagesList : list):
        formattedString = ''
        formatIdx = 0

        for msg in messagesList:
            if formatIdx >= len(format):
                formatIdx = 0

            selectedSpan = deepcopy(format[formatIdx])

            if selectedSpan.postProcessor != None:
                (msg, span) = selectedSpan.postProcessor(msg, selectedSpan)
            else:
                span = selectedSpan

            formattedString += f"{span.seperatorColor}{span.l_sep}{span.textColor}{span.textBackgroundColor}{span.textStyle}"
            
            if span.textPaddingDirection == RIGHT:
                formattedString += f"{str(msg) :<{span.textPadding}}"
            elif span.textPaddingDirection == LEFT:
                formattedString += f"{str(msg) :>{span.textPadding}}"
            else:
                formattedString += f"{str(msg).center(span.textPadding)}"
            
            formattedString += f"{Style.RESET_ALL}{span.seperatorColor}{span.r_sep}"
            formatIdx += 1

        return formattedString

    def printUsingFormat(self, format: list[BeutySpan], messagesList : list, end = '\n'):
        print(self.getFormatted(format, messagesList), end=end)
    

    def print(self, messagesList : list, end='\n'):
        if type(messagesList) == str:
            self.printUsingFormat(self.formatRules, [messagesList], end)
        else:
            self.printUsingFormat(self.formatRules, messagesList, end)

    


from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '1.0.3'
DESCRIPTION = 'Just a simple library to print your script outputs in more neat / colorful way without much overhead'
LONG_DESCRIPTION = 'Library used to display your prints in colors and more structurized using ansi color codes, it is simple library without much garbage on it'

# Setting up
setup(
    name="beuty-print",
    version=VERSION,
    author="Hex24 (Markas Vielavičius)",
    author_email="<markas.vielavicius@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    include_package_data=True,   
    install_requires=["colorama"],
    keywords=['python', 'printer', 'print', 'color', 'simple', 'format'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
    # entry_points={
    #     'console_scripts': [
    #         'beutyprint=ProxyRipper.ProxyRipper:main',
    #     ],
    # }
)
